@@ -16,3 +16,6 @@ from catalyst.contrib.data.reader import (
 
 if SETTINGS.cv_required:
     from catalyst.contrib.data.cv import ImageReader, MaskReader, ImageFolderDataset
+
+if SETTINGS.nifti_required:
+    from catalyst.contrib.data.nifti import NiftiReader
