@@ -1,3 +1,5 @@
+# flake8: noqa
+# @TODO: code formatting issue for 20.07 release
 from typing import Tuple
 from functools import partial
 
@@ -5,8 +7,8 @@ import torch
 from torch import nn
 from torch.nn import functional as F
 
-from ..abn import ABN
-from .core import _get_block
+from catalyst.contrib.models.cv.segmentation.abn import ABN
+from catalyst.contrib.models.cv.segmentation.blocks.core import _get_block  # noqa: WPS450, E501
 
 
 class PyramidBlock(nn.Module):
@@ -45,10 +47,7 @@ class PyramidBlock(nn.Module):
         h, w = x.shape[-2:]
         x = self._block(x)
         x = F.interpolate(
-            x,
-            size=(h, w),
-            mode=self.interpolation_mode,
-            align_corners=self.align_corners,
+            x, size=(h, w), mode=self.interpolation_mode, align_corners=self.align_corners,
         )
         return x
 
@@ -57,10 +56,7 @@ class PSPBlock(nn.Module):
     """@TODO: Docs. Contribution is welcome."""
 
     def __init__(
-        self,
-        in_channels: int,
-        pool_sizes: Tuple[int] = (1, 2, 3, 6),
-        use_batchnorm: bool = True,
+        self, in_channels: int, pool_sizes: Tuple[int] = (1, 2, 3, 6), use_batchnorm: bool = True,
     ):
         """@TODO: Docs. Contribution is welcome."""
         super().__init__()
@@ -82,3 +78,6 @@ class PSPBlock(nn.Module):
         xs = [stage(x) for stage in self.stages] + [x]
         x = torch.cat(xs, dim=1)
         return x
+
+
+__all__ = ["PyramidBlock", "PSPBlock"]
