@@ -1,9 +1,16 @@
+# flake8: noqa
+# @TODO: code formatting issue for 20.07 release
 import torch
 from torch import nn
 from torch.nn import functional as F
 
-from ..abn import ABN
-from .core import _get_block, _upsample, DecoderBlock, EncoderBlock
+from catalyst.contrib.models.cv.segmentation.abn import ABN
+from catalyst.contrib.models.cv.segmentation.blocks.core import (  # noqa: WPS450, E501
+    _get_block,
+    _upsample,
+    DecoderBlock,
+    EncoderBlock,
+)
 
 
 class EncoderDownsampleBlock(EncoderBlock):
@@ -23,9 +30,7 @@ class EncoderDownsampleBlock(EncoderBlock):
         """@TODO: Docs. Contribution is welcome."""
         super().__init__(in_channels, out_channels, in_strides)
         self._out_strides = (
-            in_strides * first_stride * second_stride
-            if in_strides is not None
-            else None
+            in_strides * first_stride * second_stride if in_strides is not None else None
         )
         self._block = _get_block(
             in_channels=in_channels,
@@ -71,13 +76,9 @@ class EncoderUpsampleBlock(EncoderBlock):
         if in_strides is None:
             self._out_strides = None
         elif pool_first:
-            self._out_strides = (
-                in_strides * first_stride * second_stride * 2 // upsample_scale
-            )
+            self._out_strides = in_strides * first_stride * second_stride * 2 // upsample_scale
         else:
-            self._out_strides = (
-                in_strides * first_stride * second_stride // upsample_scale
-            )
+            self._out_strides = in_strides * first_stride * second_stride // upsample_scale
         self.pool_first = pool_first
         self.upsample_scale = upsample_scale
         self.interpolation_mode = interpolation_mode
@@ -105,9 +106,7 @@ class EncoderUpsampleBlock(EncoderBlock):
     def forward(self, x: torch.Tensor) -> torch.Tensor:
         """Forward call."""
         if self.pool_first:
-            x = F.max_pool2d(
-                x, kernel_size=self.upsample_scale, stride=self.upsample_scale
-            )
+            x = F.max_pool2d(x, kernel_size=self.upsample_scale, stride=self.upsample_scale)
         x = F.interpolate(
             x,
             scale_factor=self.upsample_scale,
@@ -182,9 +181,7 @@ class DecoderConcatBlock(DecoderBlock):
         block = nn.Sequential(*layers)
         return block
 
-    def forward(
-        self, bottom: torch.Tensor, left: torch.Tensor
-    ) -> torch.Tensor:
+    def forward(self, bottom: torch.Tensor, left: torch.Tensor) -> torch.Tensor:
         """Forward call."""
         if self.aggregate_first:
             x = torch.cat([bottom, left], 1)
@@ -217,9 +214,7 @@ class DecoderSumBlock(DecoderConcatBlock):
         """
         super().__init__(enc_channels=0, **kwargs)
 
-    def forward(
-        self, bottom: torch.Tensor, left: torch.Tensor
-    ) -> torch.Tensor:
+    def forward(self, bottom: torch.Tensor, left: torch.Tensor) -> torch.Tensor:
         """Forward call."""
         if self.aggregate_first:
             x = bottom + left
@@ -242,3 +237,11 @@ class DecoderSumBlock(DecoderConcatBlock):
             x = x + left
 
         return x
+
+
+__all__ = [
+    "EncoderDownsampleBlock",
+    "EncoderUpsampleBlock",
+    "DecoderConcatBlock",
+    "DecoderSumBlock",
+]
