@@ -1,3 +1,5 @@
+# flake8: noqa
+# @TODO: code formatting issue for 20.07 release
 from typing import List
 from abc import ABC, abstractmethod
 
@@ -11,8 +13,8 @@ class BridgeSpec(ABC, nn.Module):
     def __init__(self, in_channels: List[int], in_strides: List[int]):
         """
         Args:
-            in_channels (List[int]): number of channels in the input sample
-            in_strides (List[int]): the stride of the block
+            in_channels: number of channels in the input sample
+            in_strides: the stride of the block
         """
         super().__init__()
         self._in_channels = in_channels
@@ -44,3 +46,6 @@ class BridgeSpec(ABC, nn.Module):
     def forward(self, x: List[torch.Tensor]) -> List[torch.Tensor]:
         """Forward call."""
         pass
+
+
+__all__ = ["BridgeSpec"]
