@@ -1,13 +1,15 @@
+# flake8: noqa
+# @TODO: code formatting issue for 20.07 release
 from typing import Dict, List, Union
 from pathlib import Path
 
 import torch
 from torch import nn
 
-from .bridge import BridgeSpec
-from .decoder import DecoderSpec
-from .encoder import EncoderSpec, ResnetEncoder, UnetEncoder
-from .head import HeadSpec
+from catalyst.contrib.models.cv.segmentation.bridge import BridgeSpec
+from catalyst.contrib.models.cv.segmentation.decoder import DecoderSpec
+from catalyst.contrib.models.cv.segmentation.encoder import EncoderSpec, ResnetEncoder, UnetEncoder
+from catalyst.contrib.models.cv.segmentation.head import HeadSpec
 
 
 class UnetMetaSpec(nn.Module):
@@ -77,11 +79,7 @@ class UnetSpec(UnetMetaSpec):
         )
 
         super().__init__(
-            encoder=encoder,
-            bridge=bridge,
-            decoder=decoder,
-            head=head,
-            state_dict=state_dict,
+            encoder=encoder, bridge=bridge, decoder=decoder, head=head, state_dict=state_dict,
         )
 
     def _get_components(
@@ -115,20 +113,14 @@ class ResnetUnetSpec(UnetMetaSpec):
         decoder_params = decoder_params or {}
         head_params = head_params or {}
 
-        encoder = ResnetEncoder(
-            arch=arch, pretrained=pretrained, **encoder_params
-        )
+        encoder = ResnetEncoder(arch=arch, pretrained=pretrained, **encoder_params)
 
         encoder, bridge, decoder, head = self._get_components(
             encoder, num_classes, bridge_params, decoder_params, head_params
         )
 
         super().__init__(
-            encoder=encoder,
-            bridge=bridge,
-            decoder=decoder,
-            head=head,
-            state_dict=state_dict,
+            encoder=encoder, bridge=bridge, decoder=decoder, head=head, state_dict=state_dict,
         )
 
     def _get_components(
@@ -140,3 +132,6 @@ class ResnetUnetSpec(UnetMetaSpec):
         head_params: Dict,
     ):
         raise NotImplementedError()
+
+
+__all__ = ["UnetMetaSpec", "UnetSpec", "ResnetUnetSpec"]
