@@ -1,14 +1,16 @@
-from typing import Dict  # isort:skip
+from typing import Dict
 
-from .blocks import EncoderDownsampleBlock
-from .bridge import UnetBridge
-from .core import ResnetUnetSpec, UnetSpec
-from .decoder import FPNDecoder
-from .encoder import ResnetEncoder, UnetEncoder
-from .head import FPNHead
+from catalyst.contrib.models.cv.segmentation.blocks import EncoderDownsampleBlock
+from catalyst.contrib.models.cv.segmentation.bridge import UnetBridge
+from catalyst.contrib.models.cv.segmentation.core import ResnetUnetSpec, UnetSpec
+from catalyst.contrib.models.cv.segmentation.decoder import FPNDecoder
+from catalyst.contrib.models.cv.segmentation.encoder import ResnetEncoder, UnetEncoder
+from catalyst.contrib.models.cv.segmentation.head import FPNHead
 
 
 class FPNUnet(UnetSpec):
+    """@TODO: Docs. Contribution is welcome."""
+
     def _get_components(
         self,
         encoder: UnetEncoder,
@@ -25,9 +27,7 @@ class FPNUnet(UnetSpec):
             **bridge_params
         )
         decoder = FPNDecoder(
-            in_channels=bridge.out_channels,
-            in_strides=bridge.out_strides,
-            **decoder_params
+            in_channels=bridge.out_channels, in_strides=bridge.out_strides, **decoder_params
         )
         head = FPNHead(
             in_channels=decoder.out_channels,
@@ -42,6 +42,8 @@ class FPNUnet(UnetSpec):
 
 
 class ResnetFPNUnet(ResnetUnetSpec):
+    """@TODO: Docs. Contribution is welcome."""
+
     def _get_components(
         self,
         encoder: ResnetEncoder,
@@ -52,9 +54,7 @@ class ResnetFPNUnet(ResnetUnetSpec):
     ):
         bridge = None
         decoder = FPNDecoder(
-            in_channels=encoder.out_channels,
-            in_strides=encoder.out_strides,
-            **decoder_params
+            in_channels=encoder.out_channels, in_strides=encoder.out_strides, **decoder_params
         )
         head = FPNHead(
             in_channels=decoder.out_channels,
@@ -66,3 +66,6 @@ class ResnetFPNUnet(ResnetUnetSpec):
             **head_params
         )
         return encoder, bridge, decoder, head
+
+
+__all__ = ["FPNUnet", "ResnetFPNUnet"]
