@@ -1,3 +1,5 @@
+# flake8: noqa
+# @TODO: code formatting issue for 20.07 release
 from typing import List
 from abc import ABC, abstractmethod
 
@@ -9,10 +11,7 @@ class HeadSpec(ABC, nn.Module):
     """@TODO: Docs. Contribution is welcome."""
 
     def __init__(
-        self,
-        in_channels: List[int],
-        out_channles: int,
-        in_strides: List[int] = None,
+        self, in_channels: List[int], out_channles: int, in_strides: List[int] = None,
     ):
         """@TODO: Docs. Contribution is welcome."""
         super().__init__()
@@ -24,3 +23,6 @@ class HeadSpec(ABC, nn.Module):
     def forward(self, x: List[torch.Tensor]) -> torch.Tensor:
         """Forward call."""
         pass
+
+
+__all__ = ["HeadSpec"]
