@@ -1,3 +1,4 @@
+# flake8: noqa
 # Lovasz-Softmax and Jaccard hinge loss in PyTorch
 # Maxim Berman 2018 ESAT-PSI KU Leuven (MIT License)
 
@@ -102,16 +103,12 @@ def _lovasz_hinge(logits, targets, per_image=True, ignore=None):
     if per_image:
         loss = mean(
             _lovasz_hinge_flat(
-                *_flatten_binary_scores(
-                    logit.unsqueeze(0), target.unsqueeze(0), ignore
-                )
+                *_flatten_binary_scores(logit.unsqueeze(0), target.unsqueeze(0), ignore)
             )
             for logit, target in zip(logits, targets)
         )
     else:
-        loss = _lovasz_hinge_flat(
-            *_flatten_binary_scores(logits, targets, ignore)
-        )
+        loss = _lovasz_hinge_flat(*_flatten_binary_scores(logits, targets, ignore))
     return loss
 
 
@@ -139,7 +136,7 @@ def _flatten_probabilities(probabilities, targets, ignore=None):
 
 
 def _lovasz_softmax_flat(probabilities, targets, classes="present"):
-    """The multi-class Lovasz-Softmax loss.
+    """The multiclass Lovasz-Softmax loss.
 
     Args:
         probabilities: [P, C]
@@ -173,10 +170,8 @@ def _lovasz_softmax_flat(probabilities, targets, classes="present"):
     return mean(losses)
 
 
-def _lovasz_softmax(
-    probabilities, targets, classes="present", per_image=False, ignore=None
-):
-    """The multi-class Lovasz-Softmax loss.
+def _lovasz_softmax(probabilities, targets, classes="present", per_image=False, ignore=None):
+    """The multiclass Lovasz-Softmax loss.
 
     Args:
         probabilities: [B, C, H, W]
@@ -193,17 +188,14 @@ def _lovasz_softmax(
     if per_image:
         loss = mean(
             _lovasz_softmax_flat(
-                *_flatten_probabilities(
-                    prob.unsqueeze(0), lab.unsqueeze(0), ignore
-                ),
+                *_flatten_probabilities(prob.unsqueeze(0), lab.unsqueeze(0), ignore),
                 classes=classes
             )
             for prob, lab in zip(probabilities, targets)
         )
     else:
         loss = _lovasz_softmax_flat(
-            *_flatten_probabilities(probabilities, targets, ignore),
-            classes=classes
+            *_flatten_probabilities(probabilities, targets, ignore), classes=classes
         )
     return loss
 
@@ -238,14 +230,12 @@ class LovaszLossBinary(_Loss):
 
         @TODO: Docs. Contribution is welcome.
         """
-        loss = _lovasz_hinge(
-            logits, targets, per_image=self.per_image, ignore=self.ignore
-        )
+        loss = _lovasz_hinge(logits, targets, per_image=self.per_image, ignore=self.ignore)
         return loss
 
 
 class LovaszLossMultiClass(_Loss):
-    """Creates a criterion that optimizes a multi-class Lovasz loss.
+    """Creates a criterion that optimizes a multiclass Lovasz loss.
 
     It has been proposed in `The Lovasz-Softmax loss: A tractable surrogate
     for the optimization of the intersection-over-union measure
@@ -271,14 +261,12 @@ class LovaszLossMultiClass(_Loss):
 
         @TODO: Docs. Contribution is welcome.
         """
-        loss = _lovasz_softmax(
-            logits, targets, per_image=self.per_image, ignore=self.ignore
-        )
+        loss = _lovasz_softmax(logits, targets, per_image=self.per_image, ignore=self.ignore)
         return loss
 
 
 class LovaszLossMultiLabel(_Loss):
-    """Creates a criterion that optimizes a multi-label Lovasz loss.
+    """Creates a criterion that optimizes a multilabel Lovasz loss.
 
     It has been proposed in `The Lovasz-Softmax loss: A tractable surrogate
     for the optimization of the intersection-over-union measure
