@@ -6,6 +6,8 @@ if TYPE_CHECKING:
 
 
 class ICallback:
+    """A callable abstraction for deep learning runs."""
+
     def on_experiment_start(self, runner: "IRunner") -> None:
         """Event handler for experiment start.
 
@@ -200,6 +202,13 @@ class Callback(ICallback):
 
         exception – if an Exception was raised
 
+    Abstraction, please check out implementations for more details:
+
+        - :py:mod:`catalyst.callbacks.criterion.CriterionCallback`
+        - :py:mod:`catalyst.callbacks.optimizer.OptimizerCallback`
+        - :py:mod:`catalyst.callbacks.scheduler.SchedulerCallback`
+        - :py:mod:`catalyst.callbacks.checkpoint.CheckpointCallback`
+
     .. note::
         To learn more about Catalyst Core concepts, please check out
 
@@ -207,12 +216,6 @@ class Callback(ICallback):
             - :py:mod:`catalyst.core.engine.IEngine`
             - :py:mod:`catalyst.core.callback.Callback`
 
-    Abstraction, please check out the implementations:
-
-        - :py:mod:`catalyst.callbacks.criterion.CriterionCallback`
-        - :py:mod:`catalyst.callbacks.optimizer.OptimizerCallback`
-        - :py:mod:`catalyst.callbacks.scheduler.SchedulerCallback`
-        - :py:mod:`catalyst.callbacks.checkpoint.CheckpointCallback`
     """
 
     def __init__(
@@ -456,6 +459,7 @@ class CallbackList(Callback):
 
 
 __all__ = [
+    "ICallback",
     "Callback",
     "CallbackNode",
     "CallbackOrder",
