@@ -14,7 +14,6 @@ from catalyst.core.engine import IEngine
 from catalyst.core.logger import ILogger
 from catalyst.core.misc import filter_callbacks_by_node, sort_callbacks_by_order, validate_loaders
 from catalyst.core.trial import ITrial
-from catalyst.engines.torch import DistributedDataParallelEngine
 from catalyst.typing import (
     Criterion,
     Device,
@@ -24,8 +23,10 @@ from catalyst.typing import (
     RunnerModel,
     RunnerOptimizer,
     RunnerScheduler,
+    Sampler,
     Scheduler,
 )
+from catalyst.utils.distributed import ddp_sync_run
 from catalyst.utils.misc import maybe_recursive_call, set_global_seed
 
 LOGGER = logging.getLogger(__name__)
@@ -41,6 +42,20 @@ def _has_str_intersections(origin_string: str, strings: Tuple):
     return any(x in origin_string for x in strings)
 
 
+def _get_batch_size(loader: DataLoader):
+    batch_size = loader.batch_size
+    if batch_size is not None:
+        return batch_size
+
+    batch_size = loader.batch_sampler.batch_size
+    if batch_size is not None:
+        return batch_size
+    raise NotImplementedError(
+        "No `batch_size` found,"
+        "please specity it throught `loader.batch_size`, or `loader.batch_sampler.batch_size`"
+    )
+
+
 class RunnerException(Exception):
     """Exception class for all runner errors."""
 
@@ -52,16 +67,140 @@ class IRunner(ICallback, ILogger, ABC):
     An abstraction that contains all the logic of how to run the experiment,
     stages, epochs, loaders and batches.
 
+    IRunner supports the logic for deep learning pipeline configuration with pure python code.
+    Please check the examples for intuition.
+
     Args:
         model: Torch model object
         engine: IEngine instance
 
+    Abstraction, please check out implementations for more details:
+
+        - :py:mod:`catalyst.runners.runner.Runner`
+        - :py:mod:`catalyst.runners.config.ConfigRunner`
+        - :py:mod:`catalyst.runners.hydra.HydraRunner`
+
     .. note::
         To learn more about Catalyst Core concepts, please check out
 
             - :py:mod:`catalyst.core.runner.IRunner`
             - :py:mod:`catalyst.core.engine.IEngine`
             - :py:mod:`catalyst.core.callback.Callback`
+
+    .. note::
+        Please follow the `minimal examples`_ sections for use cases.
+
+        .. _`minimal examples`: https://github.com/catalyst-team/catalyst#minimal-examples
+
+    Examples:
+
+    .. code-block:: python
+
+        import os
+        from torch import nn, optim
+        from torch.utils.data import DataLoader
+        from catalyst import dl, utils
+        from catalyst.contrib.datasets import MNIST
+        from catalyst.data import ToTensor
+
+
+        class CustomRunner(dl.IRunner):
+            def __init__(self, logdir, device):
+                super().__init__()
+                self._logdir = logdir
+                self._device = device
+
+            def get_engine(self):
+                return dl.DeviceEngine(self._device)
+
+            def get_loggers(self):
+                return {
+                    "console": dl.ConsoleLogger(),
+                    "csv": dl.CSVLogger(logdir=self._logdir),
+                    "tensorboard": dl.TensorboardLogger(logdir=self._logdir),
+                }
+
+            @property
+            def stages(self):
+                return ["train_freezed", "train_unfreezed"]
+
+            def get_stage_len(self, stage: str) -> int:
+                return 3
+
+            def get_loaders(self, stage: str):
+                loaders = {
+                    "train": DataLoader(
+                        MNIST(os.getcwd(), train=True, download=True, transform=ToTensor()),
+                        batch_size=32
+                    ),
+                    "valid": DataLoader(
+                        MNIST(os.getcwd(), train=False, download=True, transform=ToTensor()),
+                        batch_size=32
+                    ),
+                }
+                return loaders
+
+            def get_model(self, stage: str):
+                model = (
+                    self.model
+                    if self.model is not None
+                    else nn.Sequential(
+                        nn.Flatten(), nn.Linear(784, 128), nn.ReLU(), nn.Linear(128, 10)
+                    )
+                )
+                if stage == "train_freezed":
+                    # freeze layer
+                    utils.set_requires_grad(model[1], False)
+                else:
+                    utils.set_requires_grad(model, True)
+                return model
+
+            def get_criterion(self, stage: str):
+                return nn.CrossEntropyLoss()
+
+            def get_optimizer(self, stage: str, model):
+                if stage == "train_freezed":
+                    return optim.Adam(model.parameters(), lr=1e-3)
+                else:
+                    return optim.SGD(model.parameters(), lr=1e-1)
+
+            def get_scheduler(self, stage: str, optimizer):
+                return None
+
+            def get_callbacks(self, stage: str):
+                return {
+                    "criterion": dl.CriterionCallback(
+                        metric_key="loss", input_key="logits", target_key="targets"
+                    ),
+                    "optimizer": dl.OptimizerCallback(metric_key="loss"),
+                    "accuracy": dl.AccuracyCallback(
+                        input_key="logits", target_key="targets", topk_args=(1, 3, 5)
+                    ),
+                    "classification": dl.PrecisionRecallF1SupportCallback(
+                        input_key="logits", target_key="targets", num_classes=10
+                    ),
+                    "checkpoint": dl.CheckpointCallback(
+                        self._logdir,
+                        loader_key="valid",
+                        metric_key="loss",
+                        minimize=True,
+                        save_n_best=3,
+                    ),
+                }
+
+            def handle_batch(self, batch):
+                x, y = batch
+                logits = self.model(x)
+
+                self.batch = {
+                    "features": x,
+                    "targets": y,
+                    "logits": logits,
+                }
+
+        runner = CustomRunner("./logs", "cpu")
+        runner.run()
+
     """
 
     def __init__(
@@ -84,7 +223,7 @@ class IRunner(ICallback, ILogger, ABC):
         self.loggers: Dict[str, ILogger] = {}
 
         # the dataflow - model input/output and other batch tensors
-        self.batch: [Dict, torch.Tensor] = None
+        self.batch: Dict[str, torch.Tensor] = None
 
         # metrics flow - batch, loader and epoch metrics
         self.batch_metrics: BATCH_METRICS = defaultdict(None)
@@ -123,6 +262,8 @@ class IRunner(ICallback, ILogger, ABC):
         # extra
         self.exception: Exception = None
         self.need_early_stop: bool = False
+        self._stage_rank: int = -1
+        self._stage_world_size: int = -1
 
     # @TODO: remove hotfix
     @property
@@ -160,6 +301,28 @@ class IRunner(ICallback, ILogger, ABC):
         """
         return {}
 
+    @property
+    def _log_defaults(self) -> Dict:
+        return {
+            # experiment info
+            "run_key": self.run_key,
+            "global_sample_step": self.global_sample_step,
+            "global_batch_step": self.global_batch_step,
+            "global_epoch_step": self.global_epoch_step,
+            # stage info
+            "stage_key": self.stage_key,
+            "stage_epoch_len": self.stage_epoch_len,
+            "stage_epoch_step": self.stage_epoch_step,
+            "stage_batch_step": self.stage_batch_step,
+            "stage_sample_step": self.stage_sample_step,
+            # loader info
+            "loader_key": self.loader_key,
+            "loader_batch_len": self.loader_batch_len,
+            "loader_sample_len": self.loader_sample_len,
+            "loader_batch_step": self.loader_batch_step,
+            "loader_sample_step": self.loader_sample_step,
+        }
+
     @property
     @abstractmethod
     def stages(self) -> Iterable[str]:
@@ -235,9 +398,19 @@ class IRunner(ICallback, ILogger, ABC):
         """
         raise NotImplementedError
 
-    # def get_samplers(self, stage: str = None):
-    #     raise NotImplementedError
-    #
+    def get_samplers(self, stage: str = None) -> "OrderedDict[str, Sampler]":
+        """Returns samplers for a given stage.  # noqa: DAR401
+
+        Args:
+            stage: stage name of interest, like "pretrain" / "train" / "finetune" / etc
+
+        Returns:  # noqa: DAR201, DAR202
+            OrderedDict[str, Sampler]: Ordered dictionary
+                with samplers for current stage and epoch.
+
+        """
+        raise NotImplementedError
+
     # def get_transforms(self, stage: str = None):
     #     """Returns the data transforms for a given stage and dataset.
     #
@@ -362,12 +535,16 @@ class IRunner(ICallback, ILogger, ABC):
         self.criterion = self.get_criterion(stage=self.stage_key)
         return self.criterion
 
-    def _get_optimizer(self) -> Optimizer:
-        assert self.model is not None, "You need to setup model first"
+    def _get_optimizer(self, model: Model = None) -> Optimizer:
+        if model is not None:
+            self.model = model
+        # assert self.model is not None, "You need to setup model first"
         self.optimizer = self.get_optimizer(stage=self.stage_key, model=self.model)
         return self.optimizer
 
-    def _get_scheduler(self) -> Scheduler:
+    def _get_scheduler(self, optimizer: Optimizer = None) -> Scheduler:
+        if optimizer is not None:
+            self.optimizer = optimizer
         # assert self.optimizer is not None, "You need to setup optimizer first"
         self.scheduler = self.get_scheduler(stage=self.stage_key, optimizer=self.optimizer)
         return self.scheduler
@@ -384,56 +561,6 @@ class IRunner(ICallback, ILogger, ABC):
         """
         return {}
 
-    def log_metrics(self, *args, **kwargs) -> None:
-        """Logs batch, loader and epoch metrics to available loggers."""
-        for logger in self.loggers.values():
-            logger.log_metrics(
-                *args,
-                **kwargs,
-                # experiment info
-                run_key=self.run_key,
-                global_sample_step=self.global_sample_step,
-                global_batch_step=self.global_batch_step,
-                global_epoch_step=self.global_epoch_step,
-                # stage info
-                stage_key=self.stage_key,
-                stage_epoch_len=self.stage_epoch_len,
-                stage_epoch_step=self.stage_epoch_step,
-                stage_batch_step=self.stage_batch_step,
-                stage_sample_step=self.stage_sample_step,
-                # loader info
-                loader_key=self.loader_key,
-                loader_batch_len=self.loader_batch_len,
-                loader_sample_len=self.loader_sample_len,
-                loader_batch_step=self.loader_batch_step,
-                loader_sample_step=self.loader_sample_step,
-            )
-
-    def log_image(self, *args, **kwargs) -> None:
-        """Logs image to available loggers."""
-        for logger in self.loggers.values():
-            logger.log_image(
-                *args,
-                **kwargs,
-                # experiment info
-                run_key=self.run_key,
-                global_sample_step=self.global_sample_step,
-                global_batch_step=self.global_batch_step,
-                global_epoch_step=self.global_epoch_step,
-                # stage info
-                stage_key=self.stage_key,
-                stage_epoch_len=self.stage_epoch_len,
-                stage_epoch_step=self.stage_epoch_step,
-                stage_batch_step=self.stage_batch_step,
-                stage_sample_step=self.stage_sample_step,
-                # loader info
-                loader_key=self.loader_key,
-                loader_batch_len=self.loader_batch_len,
-                loader_sample_len=self.loader_sample_len,
-                loader_batch_step=self.loader_batch_step,
-                loader_sample_step=self.loader_sample_step,
-            )
-
     def log_hparams(self, *args, **kwargs) -> None:
         """Logs hyperparameters to available loggers."""
         for logger in self.loggers.values():
@@ -445,15 +572,30 @@ class IRunner(ICallback, ILogger, ABC):
                 stage_key=self.stage_key,
             )
 
+    def log_metrics(self, *args, **kwargs) -> None:
+        """Logs batch, loader and epoch metrics to available loggers."""
+        for logger in self.loggers.values():
+            logger.log_metrics(*args, **kwargs, **self._log_defaults)
+
+    def log_image(self, *args, **kwargs) -> None:
+        """Logs image to available loggers."""
+        for logger in self.loggers.values():
+            logger.log_image(*args, **kwargs, **self._log_defaults)
+
+    def log_artifact(self, *args, **kwargs) -> None:
+        """Logs artifact (file like audio, video, csv, etc.) to available loggers."""
+        for logger in self.loggers.values():
+            logger.log_artifact(*args, **kwargs, **self._log_defaults)
+
     def flush_log(self) -> None:
         """Flushes the loggers."""
         for logger in self.loggers.values():
             logger.flush_log()
 
-    def close_log(self) -> None:
+    def close_log(self, *args, **kwargs) -> None:
         """Closes the loggers."""
         for logger in self.loggers.values():
-            logger.close_log()
+            logger.close_log(*args, **kwargs)
 
     def _setup_loaders(self) -> None:
         set_global_seed(self.seed + self.engine.rank + self.global_epoch_step)
@@ -499,7 +641,14 @@ class IRunner(ICallback, ILogger, ABC):
         self.stage_epoch_step: int = 0
         self.stage_batch_step: int = 0
         self.stage_sample_step: int = 0
-        self._setup_loaders()
+
+        if self.engine.is_ddp:
+            self.engine.setup_process(rank=self._stage_rank, world_size=self._stage_world_size)
+            if not self.engine.is_master_process:
+                del self.loggers
+                self.loggers = {}
+
+        ddp_sync_run(self._setup_loaders)
         self._setup_components()
         self._setup_callbacks()
         self.log_hparams(hparams=self.hparams, scope="stage")
@@ -525,7 +674,7 @@ class IRunner(ICallback, ILogger, ABC):
         self.is_valid_loader: bool = self.loader_key.startswith("valid")
         self.is_infer_loader: bool = self.loader_key.startswith("infer")
         assert self.is_train_loader or self.is_valid_loader or self.is_infer_loader
-        self.loader_batch_size: int = self.loader.batch_size
+        self.loader_batch_size: int = _get_batch_size(self.loader)
         self.loader_batch_len: int = len(self.loader)
         self.loader_sample_len: int = len(self.loader.dataset)
         self.loader_batch_step: int = 0
@@ -549,12 +698,13 @@ class IRunner(ICallback, ILogger, ABC):
         else:
             self.batch_size = len(self.batch[0])
 
-        self.global_batch_step += 1
-        self.stage_batch_step += 1
-        self.loader_batch_step += 1
-        self.global_sample_step += self.batch_size
-        self.stage_sample_step += self.batch_size
-        self.loader_sample_step += self.batch_size
+        # we have an batch per each worker...
+        self.global_batch_step += self.engine.world_size
+        self.stage_batch_step += self.engine.world_size
+        self.loader_batch_step += self.engine.world_size
+        self.global_sample_step += self.batch_size * self.engine.world_size
+        self.stage_sample_step += self.batch_size * self.engine.world_size
+        self.loader_sample_step += self.batch_size * self.engine.world_size
         self.batch_metrics: Dict = defaultdict(None)
 
     def on_batch_end(self, runner: "IRunner"):
@@ -562,10 +712,11 @@ class IRunner(ICallback, ILogger, ABC):
         # as far as we could `backward` anything from `batch_metrics` on the nodes during training,
         # they could not be synced before, so we have to sync them in the end of the batch
         # @TODO: could be done better
-        self.batch_metrics = {
-            k: runner.engine.sync_tensor(torch.tensor(v, device=runner.device), "mean")
-            for k, v in self.batch_metrics.items()
-        }
+        if self.engine.is_ddp:
+            self.batch_metrics = {
+                k: runner.engine.sync_tensor(torch.tensor(v, device=runner.device), "mean")
+                for k, v in self.batch_metrics.items()
+            }
         self.log_metrics(metrics=self.batch_metrics, scope="batch")
 
     def on_loader_end(self, runner: "IRunner"):
@@ -582,11 +733,24 @@ class IRunner(ICallback, ILogger, ABC):
 
     def on_stage_end(self, runner: "IRunner"):
         """Event handler."""
-        self.engine.deinit_components()
+        del self.callbacks
+        self.callbacks = {}
+        del self.loaders
+        self.loaders = {}
+        self.engine.deinit_components(runner=self)
+        self.close_log(scope="stage")
+
+        # due to multiprocessing setup we have to close current loggers
+        # to prevent EOF-like errors
+        if self.engine.is_ddp:
+            self.flush_log()
+            self.close_log()
+            self.engine.cleanup_process()
 
     def on_experiment_end(self, runner: "IRunner"):
         """Event handler."""
-        self.close_log()
+        self.flush_log()
+        self.close_log(scope="experiment")
 
     def on_exception(self, runner: "IRunner"):
         """Event handler."""
@@ -607,14 +771,14 @@ class IRunner(ICallback, ILogger, ABC):
         Used to make a train/valid/infer stage during Experiment run.
 
         Args:
-            batch (Mapping[str, Any]): dictionary with data batches
-                from DataLoader.
+            batch (Mapping[str, Any]): dictionary with data batches from DataLoader.
         """
         pass
 
     def _run_batch(self) -> None:
         self._run_event("on_batch_start")
         self.handle_batch(batch=self.batch)
+        self.batch = self.engine.sync_device(self.batch)
         self._run_event("on_batch_end")
 
     def _run_loader(self) -> None:
@@ -638,11 +802,7 @@ class IRunner(ICallback, ILogger, ABC):
         self._run_event("on_epoch_end")
 
     def _run_stage(self, rank: int = -1, world_size: int = 1) -> None:
-        if isinstance(self.engine, DistributedDataParallelEngine):
-            self.engine.setup_process(rank=rank, world_size=world_size)
-            if not self.engine.is_master_process:
-                self.loggers = {}
-
+        self._stage_rank, self._stage_world_size = rank, world_size
         self._run_event("on_stage_start")
         while self.stage_epoch_step < self.stage_epoch_len:
             self._run_epoch()
@@ -654,7 +814,7 @@ class IRunner(ICallback, ILogger, ABC):
     def _run_experiment(self) -> None:
         self._run_event("on_experiment_start")
         for self.stage_key in self.stages:
-            if isinstance(self.engine, DistributedDataParallelEngine):
+            if self.engine.is_ddp:
                 # ddp-device branch
                 world_size = self.engine.world_size
                 torch.multiprocessing.spawn(
