@@ -17,6 +17,7 @@ from catalyst.data.loader import (
 from catalyst.data.sampler import (
     BalanceClassSampler,
     BalanceBatchSampler,
+    BatchBalanceClassSampler,
     DistributedSamplerWrapper,
     DynamicLenBatchSampler,
     DynamicBalanceClassSampler,
@@ -30,4 +31,6 @@ from catalyst.data.sampler_inbatch import (
     HardClusterSampler,
 )
 
+from catalyst.data.transforms import Compose, Normalize, ToTensor, to_tensor, normalize
+
 from catalyst.contrib.data import *
