@@ -1,12 +1,14 @@
-from typing import Dict, Union
+from typing import Any, Dict, Union
 from collections import OrderedDict
+import os
 
 import torch
 from torch import nn
+import torch.distributed as dist
 
 from catalyst.engines.torch import DeviceEngine, DistributedDataParallelEngine
 from catalyst.settings import SETTINGS
-from catalyst.typing import RunnerModel, RunnerOptimizer
+from catalyst.typing import Model, Optimizer, RunnerModel, RunnerOptimizer
 from catalyst.utils.misc import get_fn_default_params
 
 if SETTINGS.apex_required:
@@ -116,7 +118,7 @@ def _wrap_into_data_parallel_with_apex(
         model = {k: nn.DataParallel(v[0]) for k, v in model.items()}
         model = {k: _patch_forward(v) for k, v in model.items()}
     else:
-        raise NotImplementedError()
+        raise ValueError("Model should be ``nn.Module`` or ``dict``")
 
     return model, optimizer
 
@@ -126,28 +128,24 @@ class APEXEngine(DeviceEngine):
 
     Args:
         device: use device, default is `"cuda"`.
-        opt_level: optimization level, should be one of ``"O0"``,
-            ``"O1"``, ``"O2"`` or ``"O3"``.
+        apex_kwargs: parameters for `apex.amp.initialize`
+            except models and optimizers (they will be forwared automatically).
 
-            - ``"O0"`` - no-op training
-            - ``"O1"`` - mixed precision (FP16) training (default)
-            - ``"O2"`` - "almost" mixed precision training
-            - ``"O3"`` - another implementation of mixed precision training
-
-            Details about levels can be found here:
-            https://nvidia.github.io/apex/amp.html#opt-levels
-        keep_batchnorm_fp32: To enhance precision and enable CUDNN batchnorm
-            (which improves performance),
-            it’s often beneficial to keep batchnorm weights in FP32 even
-            if the rest of the model is FP16.
-        loss_scale: If loss_scale is a float value,
-            use this value as the static (fixed) loss scale
-            If loss_scale is the string "dynamic",
-            adaptively adjust the loss scale over time.
-            Dynamic loss scale adjustments are performed by Amp automatically.
+            Docs for `apex.amp.initialize`:
+            https://nvidia.github.io/apex/amp.html#apex.amp.initialize
 
     Examples:
 
+    .. code-block:: python
+
+        from catalyst import dl
+
+        runner = dl.SupervisedRunner()
+        runner.train(
+            engine=dl.APEXEngine(apex_kwargs=dict(opt_level="O1", keep_batchnorm_fp32=False)),
+            ...
+        )
+
     .. code-block:: python
 
         from catalyst import dl
@@ -155,7 +153,7 @@ class APEXEngine(DeviceEngine):
         class MyRunner(dl.IRunner):
             # ...
             def get_engine(self):
-                return dl.APEXEngine(opt_level="O1", keep_batchnorm_fp32=False)
+                return dl.APEXEngine(apex_kwargs=dict(opt_level="O1", keep_batchnorm_fp32=False))
             # ...
 
     .. code-block:: yaml
@@ -169,29 +167,23 @@ class APEXEngine(DeviceEngine):
 
         engine:
             _target_: APEXEngine
-            opt_level: O1
-            keep_batchnorm_fp32: false
+            apex_kwargs:
+                opt_level: O1
+                keep_batchnorm_fp32: false
 
         stages:
             ...
 
     """
 
-    def __init__(
-        self,
-        device: str = "cuda",
-        opt_level: str = "O1",
-        keep_batchnorm_fp32: bool = None,
-        loss_scale: Union[float, str] = None,
-    ):
+    def __init__(self, device: str = "cuda", apex_kwargs: Dict[str, Any] = None):
         """Init."""
         super().__init__(device)
-        self.opt_level = opt_level
-        self.keep_batchnorm_fp32 = keep_batchnorm_fp32
-        self.loss_scale = loss_scale
+        self.apex_kwargs = apex_kwargs or {}
 
     def __repr__(self) -> str:  # noqa: D105
-        return f"{self.__class__.__name__}(device='{self.device}',opt_level='{self.opt_level}')"
+        args_list = [f"device='{self._device}'", f"apex_kwargs={self.apex_kwargs}"]
+        return f"{self.__class__.__name__}(" + ",".join(args_list) + ")"
 
     def init_components(
         self, model_fn=None, criterion_fn=None, optimizer_fn=None, scheduler_fn=None,
@@ -212,20 +204,14 @@ class APEXEngine(DeviceEngine):
 
         # from official docs:
         #   https://nvidia.github.io/apex/amp.html#opt-levels-and-properties
-        model, optimizer = _initialize_apex(
-            model,
-            optimizer,
-            opt_level=self.opt_level,
-            keep_batchnorm_fp32=self.keep_batchnorm_fp32,
-            loss_scale=self.loss_scale,
-        )
+        model, optimizer = _initialize_apex(model, optimizer, **self.apex_kwargs)
 
         # scheduler
         scheduler = scheduler_fn()
         scheduler = self.sync_device(scheduler)
         return model, criterion, optimizer, scheduler
 
-    def backward_loss(self, loss, model, optimizer) -> None:
+    def backward_loss(self, loss: torch.Tensor, model: Model, optimizer: Optimizer) -> None:
         """Abstraction over ``loss.backward()`` step."""
         with amp.scale_loss(loss, optimizer) as scaled_loss:
             scaled_loss.backward()
@@ -295,23 +281,28 @@ class APEXEngine(DeviceEngine):
             amp.load_state_dict(checkpoint["amp"])
 
 
-class DataParallelApexEngine(APEXEngine):
+class DataParallelAPEXEngine(APEXEngine):
     """Apex multi-gpu training device engine.
 
     Args:
-        opt_level: optimization level, should be one of ``"O0"``,
-            ``"O1"``, ``"O2"`` or ``"O3"``.
+        apex_kwargs: parameters for `apex.amp.initialize`
+            except models and optimizers (they will be forwared automatically).
 
-            - ``"O0"`` - no-op training
-            - ``"O1"`` - mixed precision (FP16) training (default)
-            - ``"O2"`` - "almost" mixed precision training
-            - ``"O3"`` - another implementation of mixed precision training
-
-            Details about levels can be found here:
-            https://nvidia.github.io/apex/amp.html#opt-levels
+            Docs for `apex.amp.initialize`:
+            https://nvidia.github.io/apex/amp.html#apex.amp.initialize
 
     Examples:
 
+    .. code-block:: python
+
+        from catalyst import dl
+
+        runner = dl.SupervisedRunner()
+        runner.train(
+            engine=dl.DataParallelApexEngine(apex_kwargs=dict(opt_level="O1")),
+            ...
+        )
+
     .. code-block:: python
 
         from catalyst import dl
@@ -319,7 +310,7 @@ class DataParallelApexEngine(APEXEngine):
         class MyRunner(dl.IRunner):
             # ...
             def get_engine(self):
-                return dl.DataParallelApexEngine(opt_level="O1")
+                return dl.DataParallelApexEngine(apex_kwargs=dict(opt_level="O1"))
             # ...
 
     .. code-block:: yaml
@@ -333,20 +324,23 @@ class DataParallelApexEngine(APEXEngine):
 
         engine:
             _target_: DataParallelApexEngine
-            opt_level: O1
+            apex_kwargs:
+                opt_level: O1
 
         stages:
             ...
 
     """
 
-    def __init__(self, opt_level: str = "O1"):
+    def __init__(self, apex_kwargs: Dict[str, Any] = None):
         """Init."""
-        super().__init__(f"cuda:{torch.cuda.current_device()}", opt_level)
+        super().__init__(f"cuda:{torch.cuda.current_device()}", apex_kwargs)
         self.device_count = torch.cuda.device_count()
 
     def __repr__(self) -> str:  # noqa: D105
-        return f"{self.__class__.__name__}(device='{self.device}',opt_level='{self.opt_level}')"
+        return (
+            f"{self.__class__.__name__}(device='{self._device}', apex_kwargs={self.apex_kwargs})"
+        )
 
     def init_components(
         self, model_fn=None, criterion_fn=None, optimizer_fn=None, scheduler_fn=None,
@@ -364,7 +358,7 @@ class DataParallelApexEngine(APEXEngine):
         optimizer = self.sync_device(optimizer)
 
         model, optimizer = _wrap_into_data_parallel_with_apex(
-            model, optimizer, distributed_params={"opt_level": self.opt_level}
+            model, optimizer, distributed_params=self.apex_kwargs
         )
 
         # scheduler
@@ -373,42 +367,40 @@ class DataParallelApexEngine(APEXEngine):
         return model, criterion, optimizer, scheduler
 
 
-class DistributedDataParallelApexEngine(DistributedDataParallelEngine):
+class DistributedDataParallelAPEXEngine(DistributedDataParallelEngine):
     """Distributed Apex MultiGPU training device engine.
 
     Args:
-        address: process address to use
-            (required for PyTorch backend), default is `"localhost"`.
-        port: process port to listen
-            (required for PyTorch backend), default is `"12345"`.
-        backend: multiprocessing backend to use,
-            default is `"nccl"`.
-        world_size: number of processes.
-        opt_level: optimization level, should be one of ``"O0"``,
-            ``"O1"``, ``"O2"`` or ``"O3"``.
+        address: address to use for backend.
+        port: port to use for backend.
+        ddp_kwargs: parameters for `apex.parallel.DistributedDataParallel`.
+            More info here:
+            https://nvidia.github.io/apex/parallel.html#apex.parallel.DistributedDataParallel
+        process_group_kwargs: parameters for `torch.distributed.init_process_group`.
+            More info here:
+            https://pytorch.org/docs/stable/distributed.html#torch.distributed.init_process_group
+        apex_kwargs: parameters for `apex.amp.initialize`
+            except models and optimizers (they will be forwared automatically).
 
-            - ``"O0"`` - no-op training
-            - ``"O1"`` - mixed precision (FP16) training (default)
-            - ``"O2"`` - "almost" mixed precision training
-            - ``"O3"`` - another implementation of mixed precision training
-
-            Details about levels can be found here:
-            https://nvidia.github.io/apex/amp.html#opt-levels
-
-        keep_batchnorm_fp32: To enhance precision and
-            enable CUDNN batchnorm (which improves performance),
-            it’s often beneficial to keep batchnorm weights in FP32 even
-            if the rest of the model is FP16.
-        loss_scale: If loss_scale is a float value,
-            use this value as the static (fixed) loss scale.
-            If loss_scale is the string "dynamic",
-            adaptively adjust the loss scale over time.
-            Dynamic loss scale adjustments are performed by Amp automatically.
-        delay_all_reduce (bool): boolean flag for delayed all reduce,
-            default is `True`.
+            Docs for `apex.amp.initialize`:
+            https://nvidia.github.io/apex/amp.html#apex.amp.initialize
 
     Examples:
 
+    .. code-block:: python
+
+        from catalyst import dl
+
+        runner = dl.SupervisedRunner()
+        runner.train(
+            engine=dl.DistributedDataParallelApexEngine(
+                ddp_kwargs={"allreduce_always_fp32": True},
+                process_group_kwargs={"backend": "nccl"},
+                apex_kwargs={"opt_level": "O1"},
+            ),
+            ...
+        )
+
     .. code-block:: python
 
         from catalyst import dl
@@ -417,8 +409,11 @@ class DistributedDataParallelApexEngine(DistributedDataParallelEngine):
             # ...
             def get_engine(self):
                 return dl.DistributedDataParallelApexEngine(
-                    port=12345,
-                    opt_level="O1"
+                    address="0.0.0.0",
+                    port=23234,
+                    ddp_kwargs={"allreduce_always_fp32": True},
+                    process_group_kwargs={"backend": "nccl"},
+                    apex_kwargs={"opt_level": "O1"},
                 )
             # ...
 
@@ -433,8 +428,14 @@ class DistributedDataParallelApexEngine(DistributedDataParallelEngine):
 
         engine:
             _target_: DistributedDataParallelApexEngine
-            port: 12345
-            opt_level: O1
+            address: 0.0.0.0
+            port: 23234
+            ddp_kwargs:
+                allreduce_always_fp32: true
+            process_group_kwargs:
+                backend: nccl
+            apex_kwargs:
+                opt_level: O1
 
         stages:
             ...
@@ -442,36 +443,49 @@ class DistributedDataParallelApexEngine(DistributedDataParallelEngine):
 
     def __init__(
         self,
-        address: str = "localhost",
-        port: str = "12345",
-        backend: str = "nccl",
-        world_size: int = None,
-        opt_level: str = "O1",
-        keep_batchnorm_fp32: bool = None,
-        loss_scale: Union[float, str] = None,
-        delay_all_reduce: bool = True,
+        address: str = None,
+        port: Union[str, int] = None,
+        ddp_kwargs: Dict[str, Any] = None,
+        process_group_kwargs: Dict[str, Any] = None,
+        apex_kwargs: Dict[str, Any] = None,
     ):
         """Init."""
-        super().__init__()
-        self.address = address
-        self.port = port
-        self.backend = backend
-        self._rank = 0
-        self._world_size = world_size or torch.cuda.device_count()
-        self.device = None
-        self.opt_level = opt_level
-        self.delay_all_reduce = delay_all_reduce
-        self.keep_batchnorm_fp32 = keep_batchnorm_fp32
-        self.loss_scale = loss_scale
+        super().__init__(
+            address=address, port=port, ddp_kwargs=None, process_group_kwargs=process_group_kwargs
+        )
+        self.ddp_kwargs = ddp_kwargs or {}
+        self.apex_kwargs = apex_kwargs or {}
 
     def __repr__(self):  # noqa: D105
         return (
             f"{self.__class__.__name__}(address={self.address}, "
-            f"port={self.port}, backend='{self.backend}', "
-            f"rank={self._rank}, world_size={self._world_size}, "
-            f"opt_level='{self.opt_level}')"
+            f"port={self.port}, "
+            f"ddp_kwargs={self.ddp_kwargs}, "
+            f"process_group_kwargs={self.process_group_kwargs}, "
+            f"apex_kwargs={self.apex_kwargs})"
         )
 
+    def setup_process(self, rank: int = -1, world_size: int = 1):
+        """Initialize DDP variables and processes.
+
+        Args:
+            rank: process rank. Default is `-1`.
+            world_size: number of devices in netwok to expect for train.
+                Default is `1`.
+        """
+        self._rank = rank
+        self._world_size = world_size
+
+        self.process_group_kwargs["rank"] = rank
+        self.process_group_kwargs["world_size"] = world_size
+        os.environ["MASTER_ADDR"] = str(self.address)
+        os.environ["MASTER_PORT"] = str(self.port)
+
+        dist.init_process_group(**self.process_group_kwargs)
+
+        torch.cuda.set_device(int(self._rank))
+        self._device = f"cuda:{int(self._rank)}"
+
     def init_components(
         self, model_fn=None, criterion_fn=None, optimizer_fn=None, scheduler_fn=None,
     ):
@@ -485,20 +499,14 @@ class DistributedDataParallelApexEngine(DistributedDataParallelEngine):
         optimizer = optimizer_fn()
         optimizer = self.sync_device(optimizer)
 
-        model, optimizer = amp.initialize(
-            model,
-            optimizer,
-            opt_level=self.opt_level,
-            keep_batchnorm_fp32=self.keep_batchnorm_fp32,
-            loss_scale=self.loss_scale,
-        )
-        model = ApexDistributedDataParallel(model, delay_allreduce=self.delay_all_reduce)
+        model, optimizer = amp.initialize(model, optimizer, **self.apex_kwargs)
+        model = ApexDistributedDataParallel(model, **self.ddp_kwargs)
 
         scheduler = scheduler_fn()
         scheduler = self.sync_device(scheduler)
         return model, criterion, optimizer, scheduler
 
-    def backward_loss(self, loss, model, optimizer) -> None:
+    def backward_loss(self, loss: torch.Tensor, model: Model, optimizer: Optimizer) -> None:
         """Abstraction over ``loss.backward()`` step."""
         with amp.scale_loss(loss, optimizer) as scaled_loss:
             scaled_loss.backward()
@@ -568,4 +576,13 @@ class DistributedDataParallelApexEngine(DistributedDataParallelEngine):
             amp.load_state_dict(checkpoint["amp"])
 
 
-__all__ = ["APEXEngine", "DataParallelApexEngine", "DistributedDataParallelApexEngine"]
+DataParallelApexEngine = DataParallelAPEXEngine
+DistributedDataParallelApexEngine = DistributedDataParallelAPEXEngine
+
+__all__ = [
+    "APEXEngine",
+    "DataParallelAPEXEngine",
+    "DistributedDataParallelAPEXEngine",
+    "DataParallelApexEngine",
+    "DistributedDataParallelApexEngine",
+]
