@@ -14,7 +14,7 @@ from catalyst.metrics._metric import (
 )
 from catalyst.metrics._additive import AdditiveValueMetric
 from catalyst.metrics._confusion_matrix import ConfusionMatrixMetric
-from catalyst.metrics._functional_metric import FunctionalBatchMetric
+from catalyst.metrics._functional_metric import FunctionalBatchMetric, FunctionalLoaderMetric
 
 from catalyst.metrics._accuracy import AccuracyMetric, MultilabelAccuracyMetric
 from catalyst.metrics._auc import AUCMetric
@@ -23,7 +23,7 @@ from catalyst.metrics._classification import (
     MulticlassPrecisionRecallF1SupportMetric,
     MultilabelPrecisionRecallF1SupportMetric,
 )
-from catalyst.metrics._cmc_score import CMCMetric
+from catalyst.metrics._cmc_score import CMCMetric, ReidCMCMetric
 from catalyst.metrics._hitrate import HitrateMetric
 from catalyst.metrics._map import MAPMetric
 from catalyst.metrics._mrr import MRRMetric
