@@ -10,14 +10,14 @@ from catalyst.metrics.functional._misc import (
 )
 
 from catalyst.metrics.functional._accuracy import accuracy, multilabel_accuracy
-from catalyst.metrics.functional._auc import auc
+from catalyst.metrics.functional._auc import auc, binary_auc
 from catalyst.metrics.functional._average_precision import (
     average_precision,
     mean_average_precision,
     binary_average_precision,
 )
 from catalyst.metrics.functional._classification import precision_recall_fbeta_support
-from catalyst.metrics.functional._cmc_score import cmc_score, cmc_score_count
+from catalyst.metrics.functional._cmc_score import cmc_score, cmc_score_count, masked_cmc_score
 from catalyst.metrics.functional._f1_score import f1_score, fbeta_score
 from catalyst.metrics.functional._focal import (
     sigmoid_focal_loss,
