@@ -12,6 +12,8 @@ from catalyst.utils.distributed import (
     sum_reduce,
     mean_reduce,
     all_gather,
+    ddp_reduce,
+    ddp_sync_run,
 )
 
 from catalyst.utils.misc import (
@@ -35,6 +37,7 @@ from catalyst.utils.misc import (
     get_by_keys,
     convert_labels2list,
 )
+from catalyst.utils.mixup import mixup_batch
 from catalyst.utils.numpy import get_one_hot
 
 from catalyst.utils.onnx import onnx_export
