@@ -1,4 +1,4 @@
-from typing import Any, List
+from typing import Any, Callable, List
 from collections import OrderedDict
 import os
 import pickle
@@ -8,7 +8,6 @@ import subprocess
 
 import torch
 from torch import nn
-import torch.distributed
 import torch.distributed as dist
 
 from catalyst.settings import SETTINGS
@@ -16,7 +15,7 @@ from catalyst.settings import SETTINGS
 
 def _is_torch_distributed_initialized() -> bool:
     """Checks if torch.distributed is available and initialized."""
-    return torch.distributed.is_available() and torch.distributed.is_initialized()
+    return dist.is_available() and dist.is_initialized()
 
 
 def _is_slurm_available():
@@ -35,6 +34,16 @@ def _is_ddp_wrapped(model: nn.Module) -> bool:
 
         parallel_wrappers = parallel_wrappers + (apex_DDP,)
 
+    if SETTINGS.fairscale_required:
+        from fairscale.nn.data_parallel import FullyShardedDataParallel, ShardedDataParallel
+
+        parallel_wrappers = parallel_wrappers + (ShardedDataParallel, FullyShardedDataParallel)
+
+    if SETTINGS.deepspeed_required:
+        from deepspeed import DeepSpeedEngine, PipelineEngine
+
+        parallel_wrappers = parallel_wrappers + (DeepSpeedEngine, PipelineEngine)
+
     return isinstance(model, parallel_wrappers)
 
 
@@ -63,7 +72,7 @@ def get_rank() -> int:
         int: ``rank`` if torch.distributed is initialized, otherwise ``-1``
     """
     if _is_torch_distributed_initialized():
-        return torch.distributed.get_rank()
+        return dist.get_rank()
     else:
         return -1
 
@@ -207,6 +216,44 @@ def all_gather(data: Any) -> List[Any]:
     return data_list
 
 
+def ddp_reduce(tensor: torch.Tensor, mode: str, world_size: int):
+    """Syncs ``tensor`` over ``world_size`` in distributed mode.
+
+    Args:
+        tensor: tensor to sync across the processes.
+        mode: tensor synchronization type, should be one of 'sum', 'mean' or 'all'.
+        world_size: world size
+
+    Returns:
+        torch.Tensor with synchronized values.
+
+    Raises:
+        ValueError: if mode is out of ``sum``, ``mean``, ``all``.
+    """
+    if mode not in {"sum", "mean", "all"}:
+        raise ValueError(f"Unknown sync_type '{mode}'")
+    if mode == "sum":
+        return sum_reduce(tensor)
+    elif mode == "mean":
+        return mean_reduce(tensor, world_size)
+    else:
+        return all_gather(tensor)
+
+
+def ddp_sync_run(function: Callable):
+    """Runs function in a synchronous way: 0-rank first and all other processes after.
+
+    Args:
+        function: callable function
+    """
+    rank = get_rank()
+    if rank > 0:
+        dist.barrier()
+    function()
+    if rank == 0:
+        dist.barrier()
+
+
 __all__ = [
     "get_rank",
     "get_distributed_params",
@@ -214,4 +261,6 @@ __all__ = [
     "sum_reduce",
     "mean_reduce",
     "all_gather",
+    "ddp_reduce",
+    "ddp_sync_run",
 ]
